Crate jom

Crate jom 

Functions

json_to_markdown
Converts JSON data to markdown by replacing placeholders in the markdown template with values extracted from the JSON data. Placeholders should be in the form {key} or {nested.key}.