Crate jom
jom
0.1.4
All Items
Crate Items
Functions
Crate
jom
Functions

json_
to_
markdown
Converts JSON data to markdown by replacing placeholders in the markdown template with values extracted from the JSON data. Placeholders should be in the form
{key}
or
{nested.key}
.